/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.ftp.internal;

import java.net.URL;

public class FTPServerLocation {
	public static final int DEFAULT_PORT = 21;
	private URL url;
	private String username;
	private String password;
	
	/**
	 * Creates a new FTP location.
	 * 
	 * @param url URL which provides hostname and port
	 */
	public FTPServerLocation(URL url) {
		this.url = url;
		String userInfo = url.getUserInfo();
		if (userInfo != null && userInfo.length() > 0) {
			int colon = userInfo.indexOf(':');
			if (colon == -1) {
				username = userInfo;
			} else {
				username = userInfo.substring(0, colon);
				password = userInfo.substring(colon + 1);
			}
		}
	}
	
	public String getHostname() {
		return url.getHost();
	}
	
	public int getPort() {
		return url.getPort() == -1 ? DEFAULT_PORT : url.getPort();
	}
	
	public String getUsername() {
		return username;
	}
	
	public String getPassword() {
		return password;
	}
	
	/*
	 * Returns a human-readable string for debugging purposes.
	 */
	public String toString() {
		StringBuffer buf = new StringBuffer("ftp://"); //$NON-NLS-1$
		buf.append(username);
		buf.append(':');
		buf.append(password);
		buf.append('@');
		buf.append(getHostname());
		buf.append(':');
		buf.append(Integer.toString(getPort()));
		return buf.toString();
	}

	public URL getUrl() {
		return url;
	}

	public void setAuthentication(String username, String password) {
		this.username = username;
		this.password = password;
	}
}
