/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.internal.target.ui;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IResource;
import org.eclipse.jface.viewers.ILabelDecorator;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.osgi.util.NLS;
import org.eclipse.swt.graphics.Image;
import org.eclipse.team.internal.target.TeamTargetMessages;
import org.eclipse.team.internal.target.subscriber.TargetDeploymentProvider;
import org.eclipse.team.internal.ui.synchronize.SyncInfoModelElement;
import org.eclipse.team.target.DeploymentProvider;
import org.eclipse.team.target.TeamTarget;

/**
 * Append deployment provider info to decorated resources
 */
public class DeploymentProviderLabelDecorator extends LabelProvider implements ILabelDecorator {

	private String providerType;

	public DeploymentProviderLabelDecorator(String providerType) {
		this.providerType = providerType;
	}

	private String getUrl(IResource resource) {
		DeploymentProvider[] providers = TeamTarget.getDeploymentManager().getMappings(resource, providerType);
		if (providers.length > 0) {
			IContainer root = ((TargetDeploymentProvider)providers[0]).getMappedContainer();
			if (root.equals(resource)) {
				return ((TargetDeploymentProvider)providers[0]).getUrl().toExternalForm();
			}
		}
		return null;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.IBaseLabelProvider#dispose()
	 */
	public void dispose() {
		super.dispose();
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.ILabelDecorator#decorateImage(org.eclipse.swt.graphics.Image, java.lang.Object)
	 */
	public Image decorateImage(Image image, Object element) {
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.ILabelDecorator#decorateText(java.lang.String, java.lang.Object)
	 */
	public String decorateText(String text, Object element) {
		IResource resource = null;
		if (element instanceof SyncInfoModelElement) {
			resource = ((SyncInfoModelElement)element).getResource();

		} else if (element instanceof IResource) {
			resource = ((IResource)element);
		}
		if (resource != null) {
			String url = getUrl(resource);
			if (url != null) {
				text += NLS.bind(TeamTargetMessages.DeploymentProviderLabelProvider_0, new String[] { url }); //$NON-NLS-1$ //$NON-NLS-2$
			}
		}
		return text;
	}
}
