/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.internal.target.ui;

import java.util.ArrayList;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.viewers.*;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.*;
import org.eclipse.target.Site;
import org.eclipse.target.Target;
import org.eclipse.team.internal.target.TeamTargetMessages;
import org.eclipse.ui.model.WorkbenchContentProvider;
import org.eclipse.ui.model.WorkbenchLabelProvider;

/**
 * Select a site of a given type
 */
public class SiteSelectionPage extends TargetWizardPage {

	private TableViewer table;
	private Button useExistingRepo;
	private Button useNewRepo;
	private Site site;
	private String siteType;

	
	public SiteSelectionPage(String pageName, String title, String description, ImageDescriptor titleImage, String siteType) {
		super(pageName, title, titleImage);
		this.siteType = siteType;
		setDescription(description);
	}

	protected TableViewer createTable(Composite parent) {
		Table table = new Table(parent, SWT.H_SCROLL | SWT.V_SCROLL | SWT.BORDER | SWT.SINGLE | SWT.FULL_SELECTION);
		table.setLayoutData(new GridData(GridData.FILL_BOTH));
		TableLayout layout = new TableLayout();
		layout.addColumnData(new ColumnWeightData(100, true));
		table.setLayout(layout);
		TableColumn col = new TableColumn(table, SWT.NONE);
		col.setResizable(true);
		
		return new TableViewer(table);
	}
	
	public void createControl(Composite parent) {
		Composite composite = createComposite(parent, 1);
		setControl(composite);
		// set F1 help
		// TODO: WorkbenchHelp.setHelp(composite, IHelpContextIds.TARGET_NEW_SITE_PAGE);
		
		createWrappingLabel(composite, TeamTargetMessages.SiteSelectionPage_0, 0, 1); //$NON-NLS-1$

		useNewRepo = createRadioButton(composite, TeamTargetMessages.SiteSelectionPage_1, 1); //$NON-NLS-1$
		
		useExistingRepo = createRadioButton(composite, TeamTargetMessages.SiteSelectionPage_2, 1); //$NON-NLS-1$
		table = createTable(composite);
		table.setContentProvider(new WorkbenchContentProvider());
		table.setLabelProvider(new WorkbenchLabelProvider());
		
		table.addSelectionChangedListener(new ISelectionChangedListener() {
			public void selectionChanged(SelectionChangedEvent event) {
				site = (Site)((IStructuredSelection)table.getSelection()).getFirstElement();
				setPageComplete(site != null);
			}
		});

		useExistingRepo.addListener(SWT.Selection, new Listener() {
			public void handleEvent(Event event) {
				if (useExistingRepo.getSelection()) {
					table.getTable().setEnabled(true);
					site = (Site)((IStructuredSelection)table.getSelection()).getFirstElement();
					setPageComplete(site != null);
				} else {
					table.getTable().setEnabled(false);
					site = null;
					setPageComplete(true);
				}
			}
		});
		
		useNewRepo.addListener(SWT.Selection, new Listener() {
			public void handleEvent(Event event) {
				if (useNewRepo.getSelection()) {
					SiteSelectionPage.this.setPageComplete(true);
				}
			}
		});

		initializeValues();
		Dialog.applyDialogFont(parent);
	}

	/**
	 * Initializes states of the controls.
	 */
	private void initializeValues() {
		Site[] sites = getSites();
		table.setInput(new SiteViewerInput(sites));
		if (sites.length == 0) {
			useNewRepo.setSelection(true);	
		} else {
			useExistingRepo.setSelection(true);
			table.setSelection(new StructuredSelection(sites[0]));
		}
	}
	
	private Site[] getSites() {
		Site[] sites = Target.getSiteManager().getSites();
		java.util.List result = new ArrayList();
		for (int i = 0; i < sites.length; i++) {
			Site site = sites[i];
			if (site.getTypeId().equals(siteType)) {
				result.add(site);
			}
		}
		return (Site[]) result.toArray(new Site[result.size()]);
	}

	public Site getSite() {
		return site;
	}

}
